.. _spkg_sagemath_doc_html:

sagemath_doc_html: SageMath documentation in HTML format
==================================================================

Upon installation, this package builds the SageMath documentation
in HTML format.

It is a standard package.  It is built on every invocation
of ``make`` or ``make all``, but not on ``make build``.
The documentation build can also be run separately using
``make doc-html``.

Type
----

optional


Dependencies
------------

- $(SAGERUNTIME)
- :ref:`spkg_conway_polynomials`
- :ref:`spkg_elliptic_curves`
- :ref:`spkg_fpylll`
- :ref:`spkg_furo`
- :ref:`spkg_graphs`
- :ref:`spkg_ipykernel`
- :ref:`spkg_ipywidgets`
- :ref:`spkg_jupyter_client`
- :ref:`spkg_mathjax`
- :ref:`spkg_matplotlib`
- :ref:`spkg_maxima`
- :ref:`spkg_meson_python`
- :ref:`spkg_mpmath`
- :ref:`spkg_networkx`
- :ref:`spkg_pillow`
- :ref:`spkg_pplpy_doc`
- :ref:`spkg_sage_docbuild`
- sagelib
- :ref:`spkg_sagemath_cmr`
- :ref:`spkg_sagemath_fricas`
- :ref:`spkg_sagemath_frobby`
- :ref:`spkg_sagemath_gfan`
- :ref:`spkg_sagemath_kenzo`
- :ref:`spkg_sagemath_latte_4ti2`
- :ref:`spkg_sagemath_msolve`
- :ref:`spkg_sagemath_qepcad`
- :ref:`spkg_sagemath_rubiks`
- :ref:`spkg_scipy`
- :ref:`spkg_sphinx`
- :ref:`spkg_sphinx_copybutton`
- :ref:`spkg_sphinx_inline_tabs`
- :ref:`spkg_sympy`
- :ref:`spkg_tachyon`
- :ref:`spkg_typing_extensions`

Version Information
-------------------

package-version.txt::

    10.6.1.rc2

version_requirements.txt::

    passagemath-doc-html == 10.6.1rc2


Equivalent System Packages
--------------------------

(none known)

